@@ -94,7 +94,7 @@ test_that("lm objects are handled correctly", {
 })
 
 # Only run if installed
-if("arm" %in% installed.packages())
+if(require("arm"))
 {
   test_that("bayesglm objects are handled correctly", {
     mod1 <- arm::bayesglm(Sepal.Length ~ Sepal.Width + Petal.Length + Petal.Width + Species,
@@ -145,7 +145,7 @@ if("arm" %in% installed.packages())
 }
 
 # Only run if installed
-if("mboost" %in% installed.packages())
+if(require("mboost"))
 {
   test_that("glmboost objects are handled correctly", {
     mod1 <- mboost::glmboost(Sepal.Length ~ Sepal.Width + Petal.Length + Petal.Width + Species,
@@ -181,7 +181,7 @@ if("mboost" %in% installed.packages())
 }
 
 # Only run if installed
-if("glmnet" %in% installed.packages())
+if(require("glmnet"))
 {
   test_that("cv.glmnet objects are handled correctly", {
     mod1 <- glmnet::cv.glmnet(as.matrix(datasets::iris[, c("Sepal.Width", "Petal.Length", "Petal.Width")]),
